@@ -5,7 +5,7 @@ Custom exceptions
 
 
 class BaseException(Exception):
-    def __init__(self, message=''):
+    def __init__(self, message=""):
         self.message = message
 
 
@@ -13,6 +13,7 @@ class MissingMandatoryArgument(BaseException):
     """
     Raised when a mandatory argument is missing
     """
+
     pass
 
 
@@ -20,6 +21,7 @@ class InstanceNotFound(BaseException):
     """
     Raised when no instance could be found
     """
+
     pass
 
 
@@ -27,4 +29,5 @@ class MultipleInstanceFound(BaseException):
     """
     Raised when no instance could be found
     """
+
     pass
