@@ -393,7 +393,6 @@ class BaseMeasureCompiler(object):
         Insert common measures in the grids if not set yet
         """
         for grid_item in self.processed_grids:
-            logger.debug("Completing grid {}".format(grid_item.grid.id))
             measures = grid_item.get_measures()
             for measure_type in self.common_measure_types:
                 measure = measures.get(measure_type.id)
@@ -404,12 +403,6 @@ class BaseMeasureCompiler(object):
                     )
                     grid_item.store_measure(measure)
                 else:
-                    logger.debug(
-                        "Updating the order of the given measure {} :"
-                        " was {} becomes {}".format(
-                            measure.label, measure.order, measure_type.order
-                        )
-                    )
                     measure.order = measure_type.order
                     self.session.merge(measure)
 
@@ -472,11 +465,28 @@ enDI
             len(grids)
         )
 
+    def _get_date_to_use_for_grid(self):
+        date_to_use = self.upload.updated_at.date()
+        this_year = datetime.datetime.today().year
+
+        # If synchronized accounting and écritures from last year
+        if (
+            self.upload.filetype == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
+            and self.upload.date.year < this_year
+        ):
+            # Only works for 31/12 exercice closure, not a problem as long as
+            # synchronized accounting works year by year
+            date_to_use = datetime.date(day=31, month=12, year=self.upload.date.year)
+
+        return date_to_use
+
     def get_cache_key_from_operation(self, operation):
         """
         Build a cache key based on the given operation object
         """
-        key = (operation.company_id, self.upload.updated_at.date())
+        date_to_use = self._get_date_to_use_for_grid()
+        key = (operation.company_id, date_to_use)
+
         return key
 
     def get_cache_key_from_grid(self, grid):
@@ -492,9 +502,10 @@ enDI
 
         Query filters should match the get_cache_key_from_operation options
         """
+        date_to_use = self._get_date_to_use_for_grid()
         query = (
             TreasuryMeasureGrid.query()
-            .filter_by(date=self.upload.updated_at.date())
+            .filter_by(date=date_to_use)
             .filter_by(company_id=operation.company_id)
         )
 
@@ -508,8 +519,9 @@ enDI
         :param obj operation: The AccountingOperation from which we build
         measure
         """
+        date_to_use = self._get_date_to_use_for_grid()
         return TreasuryMeasureGrid(
-            date=self.upload.updated_at.date(),
+            date=date_to_use,
             company_id=operation.company_id,
             upload=self.upload,
         )
@@ -684,22 +696,7 @@ def send_error(request, mail_addresses, type_label, message):
             logger.exception("Error sending email")
 
 
-def _collect_operations(upload_id, data_type, upload_date):
-    """
-    Return the operations needed.
-    Collect the operations ("écritures") according to the "exercice fiscal".
-    If the "exercice" has been set "closed" in enDI we don't collect the
-    operation of former year (because à-nouveau operation have been done by
-    the accountant.
-    For now, this function is only for the treasury meausures, in the future
-    it might also be for the income statement measure.
-    """
-    logger.debug(u"Collecting operations for {} upload".format(upload_id))
-
-    # Reference year for collecting data
-    current_year = upload_date.year
-    former_closure_year = current_year - 1
-
+def get_closure_day_and_month():
     # Get config from main app
     config = get_config()
 
@@ -721,6 +718,18 @@ def _collect_operations(upload_id, data_type, upload_date):
         closure_day = 31
         closure_month = 12
 
+    return closure_day, closure_month
+
+
+def get_current_exercice_dates(upload_date):
+    """
+    Return the dates of current exercice according to the upload_date
+    """
+    # Reference year for collecting data
+    current_year = upload_date.year
+
+    closure_day, closure_month = get_closure_day_and_month()
+
     # Find exercice begining day and month
     temp_date = date(current_year, closure_month, closure_day) + datetime.timedelta(
         days=1
@@ -779,6 +788,26 @@ def _collect_operations(upload_id, data_type, upload_date):
         )
     )
 
+    return current_exercice_begining_date, current_exercice_end_date
+
+
+def _collect_operations(upload_id, data_type, upload_date):
+    """
+    Return the operations needed.
+    Collect the operations ("écritures") according to the "exercice fiscal".
+    If the "exercice" has been set "closed" in enDI we don't collect the
+    operation of former year (because à-nouveau operation have been done by
+    the accountant.
+    For now, this function is only for the treasury meausures, in the future
+    it might also be for the income statement measure.
+    """
+    logger.debug(u"Collecting operations for {} upload".format(upload_id))
+
+    (
+        current_exercice_begining_date,
+        current_exercice_end_date,
+    ) = get_current_exercice_dates(upload_date)
+
     current_exercice_operations = (
         AccountingOperation.query()
         .filter(
@@ -796,14 +825,12 @@ def _collect_operations(upload_id, data_type, upload_date):
         )
     )
 
-    # Adding last exercice operations if needed (dans les cas ou les report
-    # d'à nouveau n'ont pas encore été fait)
-    # Only for synchronised  operations (remontée automatique)
+    # Adding last exercice operations if needed
     if data_type != AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
         return current_exercice_operations
 
-    # Look into AccountingClosure model to check if closure for current year
-    # has been done
+    # Has the closure been done for former year ?
+    former_closure_year = upload_date.year - 1
     former_year_closure = (
         AccountingClosure.query().filter_by(year=former_closure_year).first()
     )
@@ -815,20 +842,11 @@ def _collect_operations(upload_id, data_type, upload_date):
     logger.info(u"{} closure is done : {}".format(former_closure_year, closure_is_done))
 
     if not closure_is_done:
-        # Find date of last exercice
         last_exercice_begining_date = current_exercice_begining_date - relativedelta(
             years=1
         )
         last_exercice_end_date = current_exercice_end_date - relativedelta(years=1)
 
-        logger.info(
-            "Last exercice start the {} and ends the\
-                {}".format(
-                last_exercice_begining_date, last_exercice_end_date
-            )
-        )
-
-        # Select operations from last "exercice"
         last_exercice_operations = (
             AccountingOperation.query()
             .filter(
@@ -851,6 +869,15 @@ def _collect_operations(upload_id, data_type, upload_date):
     return current_exercice_operations
 
 
+def get_upload_from_id(upload_id):
+    upload = AccountingOperationUpload.get(upload_id)
+    if upload is None:
+        raise Exception(
+            "No AccountingOperationUpload instance with id {}".format(upload_id)
+        )
+    return upload
+
+
 @celery_app.task(bind=True)
 def compile_measures_task(self, upload_id, grid_type=None):
     """
@@ -862,19 +889,11 @@ def compile_measures_task(self, upload_id, grid_type=None):
         logger.info("Only compiling {} grids".format(grid_type))
 
     transaction.begin()
-    upload = AccountingOperationUpload.get(upload_id)
-    if upload is None:
-        raise Exception(
-            "No AccountingOperationUpload instance with id {}".format(upload_id)
-        )
+    upload = get_upload_from_id(upload_id)
 
     operations = None
     if grid_type == "treasury":
-        # We use created_at date, because his year is necessarily
-        # into the requested exercice for computing the measures
-        operations = _collect_operations(
-            upload_id, upload.filetype, upload.created_at.date()
-        )
+        operations = _collect_operations(upload_id, upload.filetype, upload.date)
     else:
         # Pour l'instant _collect_operations ne concerne que les états de
         # trésorerie, à terme quand nous voudrons présenter les comptes de
@@ -960,7 +979,7 @@ since yesterday"
                     operations = _collect_operations(
                         upload.id,
                         upload_object.filetype,
-                        upload_object.created_at.date(),
+                        upload_object.date,
                     )
                 else:
                     operations = (
