@@ -72,20 +72,24 @@ def _add_o2m_headers_to_writer(writer, query, id_key):
     to it through a userdatas_id foreign key)
     """
     from endi_base.models.base import DBSESSION
+
     new_headers = []
     for header in writer.headers:
-        if isinstance(header['__col__'], RelationshipProperty):
-            if header['__col__'].uselist:
-                class_ = header['__col__'].mapper.class_
+        if isinstance(header["__col__"], RelationshipProperty):
+            if header["__col__"].uselist:
+                class_ = header["__col__"].mapper.class_
                 # On compte le nombre maximum d'objet lié que l'on rencontre
                 # dans la base
                 if not hasattr(class_, id_key):
                     continue
 
-                count = DBSESSION().query(
-                    label("nb", func.count(class_.id))
-                ).group_by(getattr(class_, id_key)).order_by(
-                    desc("nb")).first()
+                count = (
+                    DBSESSION()
+                    .query(label("nb", func.count(class_.id)))
+                    .group_by(getattr(class_, id_key))
+                    .order_by(desc("nb"))
+                    .first()
+                )
 
                 if count is not None:
                     count = count[0]
@@ -96,26 +100,21 @@ def _add_o2m_headers_to_writer(writer, query, id_key):
                 # configuré, On rajoute des colonnes "date 1" "date 2" dans
                 # notre sheet principale
                 for index in range(0, count):
-                    if 'flatten' in header:
-                        flatten_keys = header['flatten']
-                        if not hasattr(flatten_keys, '__iter__'):
+                    if "flatten" in header:
+                        flatten_keys = header["flatten"]
+                        if not hasattr(flatten_keys, "__iter__"):
                             flatten_keys = [flatten_keys]
 
                         for flatten_key, flatten_label in flatten_keys:
                             new_header = {
-                                '__col__': header['__col__'],
-                                'label': u"%s %s %s" % (
-                                    header['label'],
-                                    flatten_label,
-                                    index + 1),
-                                'key': header['key'],
-                                'name': u"%s_%s_%s" % (
-                                    header['name'],
-                                    flatten_key,
-                                    index + 1
-                                ),
-                                'related_key': flatten_key,
-                                'index': index
+                                "__col__": header["__col__"],
+                                "label": u"%s %s %s"
+                                % (header["label"], flatten_label, index + 1),
+                                "key": header["key"],
+                                "name": u"%s_%s_%s"
+                                % (header["name"], flatten_key, index + 1),
+                                "related_key": flatten_key,
+                                "index": index,
                             }
                             new_headers.append(new_header)
 
@@ -128,7 +127,7 @@ def _get_tmp_directory_path():
     Return the tmp filepath configured in the current configuration
     :param obj request: The pyramid request object
     """
-    asset_path_spec = get_setting('endi.static_tmp', mandatory=True)
+    asset_path_spec = get_setting("endi.static_tmp", mandatory=True)
     return asset_path_spec
 
 
@@ -140,8 +139,8 @@ def _get_tmp_filepath(directory, basename, extension):
     :returns: A path to a non existing file
     :rtype: str
     """
-    if not extension.startswith('.'):
-        extension = u'.' + extension
+    if not extension.startswith("."):
+        extension = u"." + extension
 
     filepath = mktemp(prefix=basename, suffix=extension, dir=directory)
     while os.path.exists(filepath):
@@ -153,13 +152,13 @@ def _get_open_file(filepath, extension):
     """
     Get the appropriate writing mode regarding the provided extension
     """
-    if extension == 'csv':
-        return open(filepath, 'w', newline='')
+    if extension == "csv":
+        return open(filepath, "w", newline="")
     else:
-        return open(filepath, 'wb')
+        return open(filepath, "wb")
 
 
-@cache_region('default_term')
+@cache_region("default_term")
 def _write_file_on_disk(tmpdir, model_type, ids, filename, extension):
     """
     Return a path to a generated file
@@ -175,36 +174,32 @@ def _write_file_on_disk(tmpdir, model_type, ids, filename, extension):
     """
     logger.debug(" No file was cached yet")
     config = MODELS_CONFIGURATION[model_type]
-    model = config['factory']
+    model = config["factory"]
     query = model.query()
     if ids is not None:
         query = query.filter(model.id.in_(ids))
 
     options = {}
-    if 'excludes' in config:
-        options['excludes'] = config['excludes']
-    if 'order' in config:
-        options['order'] = config['order']
-    if extension == 'ods':
+    if "excludes" in config:
+        options["excludes"] = config["excludes"]
+    if "order" in config:
+        options["order"] = config["order"]
+    if extension == "ods":
         writer = SqlaOdsExporter(model=model, **options)
-    elif extension == 'xls':
+    elif extension == "xls":
         writer = SqlaXlsExporter(model=model, **options)
-    elif extension == 'csv':
+    elif extension == "csv":
         writer = SqlaCsvExporter(model=model, **options)
 
-    writer = _add_o2m_headers_to_writer(
-        writer,
-        query,
-        config['foreign_key_name']
-    )
+    writer = _add_o2m_headers_to_writer(writer, query, config["foreign_key_name"])
 
-    if 'hook_init' in config:
-        writer = config['hook_init'](writer, query)
+    if "hook_init" in config:
+        writer = config["hook_init"](writer, query)
 
     for item in query:
         writer.add_row(item)
-        if 'hook_add_row' in config:
-            config['hook_add_row'](writer, item)
+        if "hook_add_row" in config:
+            config["hook_add_row"](writer, item)
 
     filepath = _get_tmp_filepath(tmpdir, filename, extension)
     logger.debug(" + Writing file to %s" % filepath)
@@ -216,8 +211,7 @@ def _write_file_on_disk(tmpdir, model_type, ids, filename, extension):
 
 
 @celery_app.task(bind=True)
-def export_to_file(self, job_id, model_type, ids, filename='test',
-                   file_format='ods'):
+def export_to_file(self, job_id, model_type, ids, filename="test", file_format="ods"):
     """
     Export the datas provided in t)he given query to ods format and generate a
 
@@ -255,12 +249,8 @@ def export_to_file(self, job_id, model_type, ids, filename='test',
         transaction.abort()
         logger.exception("Error while generating file")
         errors = [GENERATION_ERROR_MESSAGE % job_id]
-        utils.record_failure(
-            FileGenerationJob, job_id, errors
-        )
+        utils.record_failure(FileGenerationJob, job_id, errors)
     else:
-        utils.record_completed(
-            FileGenerationJob, job_id, filename=result_filename
-        )
+        utils.record_completed(FileGenerationJob, job_id, filename=result_filename)
 
     return ""
