@@ -49,11 +49,9 @@ def get_job(celery_request, job_model, job_id):
     job = None
     while current_time <= TIMEOUT and job is None:
         try:
-            job = DBSESSION().query(job_model).filter(
-                job_model.id == job_id
-            ).one()
+            job = DBSESSION().query(job_model).filter(job_model.id == job_id).one()
             job.jobid = celery_request.id
-            if job.status not in ('planned'):
+            if job.status not in ("planned"):
                 logger.error(u"Job has already been launched")
                 job = None
         except NoResultFound:
@@ -123,6 +121,7 @@ def _record_running(job):
     """
     job.status = "running"
     from endi_base.models.base import DBSESSION
+
     DBSESSION().merge(job)
 
 
@@ -158,9 +157,8 @@ def _record_job_status(job_model, job_id, status_str):
     """
     # We fetch the job again since we're in a new transaction
     from endi_base.models.base import DBSESSION
-    job = DBSESSION().query(job_model).filter(
-        job_model.id == job_id
-    ).first()
+
+    job = DBSESSION().query(job_model).filter(job_model.id == job_id).first()
     job.status = status_str
     return job
 
@@ -170,9 +168,9 @@ def record_failure(job_model, job_id, e=None, **kwargs):
     Record a job's failure
     """
     transaction.begin()
-    job = _record_job_status(job_model, job_id, 'failed')
+    job = _record_job_status(job_model, job_id, "failed")
     # We append an error
-    if hasattr(job, 'error_messages') and e:
+    if hasattr(job, "error_messages") and e:
         job.error_messages = e
 
     for key, value in kwargs.items():
@@ -187,7 +185,7 @@ def record_completed(job_model, job_id, **kwargs):
     Record job's completion and set additionnal arguments
     """
     transaction.begin()
-    job = _record_job_status(job_model, job_id, 'completed')
+    job = _record_job_status(job_model, job_id, "completed")
     for key, value in kwargs.items():
         setattr(job, key, value)
     transaction.commit()
@@ -205,14 +203,14 @@ def check_alive():
     return_msg = None
     try:
         from celery.app.control import Inspect
+
         insp = Inspect(app=celery_app)
 
         stats = insp.stats()
         if not stats:
             return_code = False
             return_msg = (
-                u"Le service backend ne répond pas "
-                u"(Celery service not available)."
+                u"Le service backend ne répond pas " u"(Celery service not available)."
             )
     except (Exception, ConnectionError) as e:
         return_code = False
